"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const perf_hooks_1 = require("perf_hooks");
const taskId_1 = require("../task/taskId");
let observer;
let reportSummaryPromise;
function initializePerformance(context) {
    const { measures } = context;
    reportSummaryPromise = new Promise((resolve, reject) => {
        observer = new perf_hooks_1.PerformanceObserver((list, observer) => {
            // Pull out all of the measurements.
            list.getEntriesByType("measure").forEach((entry) => {
                measures.push(entry);
                if (entry.name === "measure:all") {
                    resolve(measures);
                }
            });
        });
        observer.observe({ entryTypes: ["measure"], buffered: true });
    });
}
exports.initializePerformance = initializePerformance;
function markStart(marker) {
    return perf_hooks_1.performance.mark(`start:${marker}`);
}
exports.markStart = markStart;
function markEnd(marker) {
    return perf_hooks_1.performance.mark(`end:${marker}`);
}
exports.markEnd = markEnd;
function measure(marker) {
    return perf_hooks_1.performance.measure(`measure:${marker}`, `start:${marker}`, `end:${marker}`);
}
exports.measure = measure;
async function reportSummary(context) {
    const { command } = context;
    const measures = await reportSummaryPromise;
    console.log(measures
        .map((measure) => {
        const tag = measure.name.replace(/^measure:/, "");
        if (tag === "all") {
            return `The command "${command}" took ${(measure.duration / 1000).toFixed(2)}s`;
        }
        else {
            const [pkg, task] = taskId_1.getPackageTaskFromId(tag);
            return `[${pkg}${task ? ` - ${task}` : ""}] took ${(measure.duration / 1000).toFixed(2)}s`;
        }
    })
        .join("\n"));
}
exports.reportSummary = reportSummary;
