"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internalDeps_1 = require("../monorepo/internalDeps");
const taskId_1 = require("./taskId");
const generateTask_1 = require("./generateTask");
const cacheTasks_1 = require("../cache/cacheTasks");
/**
 * identify and create a realized task dependency map (discovering)
 */
function discoverTaskDeps(context) {
    const { allPackages, defaultPipeline, taskDepsGraph, tasks } = context;
    for (const [pkg, info] of Object.entries(allPackages)) {
        const pipeline = info.pipeline || defaultPipeline;
        for (const [task, taskDeps] of Object.entries(pipeline)) {
            const taskId = taskId_1.getTaskId(pkg, task);
            if (isValidTaskId(taskId, allPackages)) {
                if (taskDeps.length > 0) {
                    for (const taskDep of taskDeps) {
                        if (taskDep.startsWith("^")) {
                            // add task dep from all the package deps within repo
                            const dependentPkgs = internalDeps_1.getInternalDeps(info, allPackages);
                            const taskName = taskDep.slice(1);
                            for (const depPkg of dependentPkgs) {
                                createDep(taskId, taskId_1.getTaskId(depPkg, taskName), context);
                            }
                        }
                        else {
                            // add task dep from same package
                            createDep(taskId, taskId_1.getTaskId(pkg, taskDep), context);
                        }
                    }
                }
                else {
                    taskDepsGraph.push(["", taskId]);
                    tasks.set("", () => Promise.resolve());
                }
            }
        }
    }
}
exports.discoverTaskDeps = discoverTaskDeps;
function isValidTaskId(taskId, allPackages) {
    const [pkg, task] = taskId_1.getPackageTaskFromId(taskId);
    return ([cacheTasks_1.ComputeHashTask, cacheTasks_1.CachePutTask, cacheTasks_1.CacheFetchTask].includes(task) ||
        Object.keys(allPackages[pkg].scripts || {}).includes(task));
}
function createDep(taskId, depTaskId, context) {
    const { tasks, taskDepsGraph, allPackages, command } = context;
    if (!isValidTaskId(depTaskId, allPackages)) {
        return;
    }
    taskDepsGraph.push([depTaskId, taskId]);
    if (!tasks.get(depTaskId)) {
        tasks.set(depTaskId, () => generateTask_1.generateTask(depTaskId, context));
    }
    if (!tasks.get(taskId)) {
        tasks.set(taskId, () => generateTask_1.generateTask(taskId, context));
    }
}
