"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const taskId_1 = require("./taskId");
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
const backfill_1 = require("../cache/backfill");
const ansiReporter_1 = require("../reporter/ansiReporter");
const taskWrapper_1 = require("./taskWrapper");
function npmTask(taskId, context) {
    const [pkg, task] = taskId_1.getPackageTaskFromId(taskId);
    const { allPackages } = context;
    return taskWrapper_1.taskWrapper(taskId, () => new Promise((resolve, reject) => {
        if (backfill_1.cacheHits[pkg]) {
            console.log(`Cache Hit! Skipping: ${pkg} - ${task}`);
            return resolve();
        }
        if (!allPackages[pkg].scripts[task]) {
            console.log(`Empty script detected: ${pkg} - ${task}`);
            return resolve();
        }
        const cp = child_process_1.spawn("npm.cmd", ["run", task], {
            cwd: path_1.default.dirname(allPackages[pkg].packageJsonPath),
            stdio: "pipe",
        });
        cp.stdout.on("data", (data) => {
            data
                .toString()
                .split(/\n/)
                .forEach((line) => {
                ansiReporter_1.reportTaskLog(taskId, line, context);
            });
        });
        cp.stderr.on("data", (data) => {
            data
                .toString()
                .split(/\n/)
                .forEach((line) => {
                ansiReporter_1.reportTaskLog(taskId, line, context);
            });
        });
        cp.on("exit", (code) => {
            if (code === 0) {
                return resolve();
            }
            reject();
        });
    }), context);
}
exports.npmTask = npmTask;
