"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const taskId_1 = require("./taskId");
const backfill_1 = require("../cache/backfill");
const p_graph_1 = __importDefault(require("p-graph"));
const cacheTasks_1 = require("../cache/cacheTasks");
const performance_1 = require("../performance");
async function runTasks(context) {
    const { command, profiler } = context;
    performance_1.initializePerformance(context);
    performance_1.markStart("all");
    console.log(`Executing command "${context.command}"`);
    cacheTasks_1.generateCacheTasks(context);
    await p_graph_1.default(context.tasks, context.taskDepsGraph).run((graph) => {
        const taskIds = [...graph.keys()].filter((k) => {
            const [pkg, task] = taskId_1.getPackageTaskFromId(k);
            return (task === command &&
                !backfill_1.cacheHits[pkg] &&
                pkg === "@ms/office-online-build-tools");
        });
        return taskIds;
    });
    profiler.output();
    performance_1.markEnd("all");
    performance_1.measure("all");
    await performance_1.reportSummary(context);
}
exports.runTasks = runTasks;
